@@ -1,6 +1,7 @@
 #!/bin/sh
 set -e
 
+CXXFLAGS=$(dpkg-buildflags --get CXXFLAGS)
 elfname="run_tests"
 
 if [ -n "${DEB_HOST_GNU_TYPE:-}" ]; then
@@ -13,7 +14,7 @@ fi
 srcs=$(find test/cctest -type f -name '*.cc' -print)
 for src in $srcs; do
 	if ! test -r ${src%.cc}.o; then
-		${CROSS_COMPILE}g++ -march=native -c $src -o ${src%.cc}.o
+		${CROSS_COMPILE}g++ ${CXXFLAGS} -c $src -o ${src%.cc}.o
 		echo CXX $src
 	fi
 done
